//*****************************************************************************
// Description     : Declaration of functions and structure for controlling device
// Target Device   : APU101
// Target Platform : Linux, C
// Date            : July 2017
// Version         : 1.0
//*****************************************************************************
#ifndef __DEVICE_H__
#define __DEVICE_H__

#include "sys_compatible.h"
#include "sitcp.h"
#include "command.h"
#include "device_define.h"


//********** alias structure *******************
#define DEVICE_COM_INFO     SITCP_COM     // structure for command communication


//********** alias function *******************
#define device_connect      sitcp_connect
#define device_disconnect   sitcp_disconnect
#define device_write_16bit  sitcp_write_16bit
#define device_write_48bit  sitcp_write_48bit


//********** macro function *******************
// stop measurement
#define device_stop_measurement(pCmd)  \
            device_write_16bit(pCmd, DEVICE_COMMAND_AQS, DEVICE_PARAM_AQS_STOP)

// convert msec to count
#define device_msec2count(msec)     \
            (((unsigned qword)(msec) * 1000000UL) / (unsigned qword)(DEVICE_CNT_PER_NSEC))
// convert count to msec
#define device_count2msec(count)    \
            (((unsigned qword)(count) * (unsigned qword)(DEVICE_CNT_PER_NSEC)) / 1000000UL)


//********** prototype declaration **********
extern int device_write_3step(DEVICE_COM_INFO *, unsigned int);
extern int device_start_measurement(DEVICE_COM_INFO *);
extern int device_read_status(DEVICE_COM_INFO *,
                              unsigned short *, unsigned qword *,
                              unsigned int *, unsigned int *);
extern int device_read_histogram(DEVICE_COM_INFO*, char*, int, int);


#endif // __DEVICE_H__
